---
title: Android
---

We provide two Android CI runners to the `elixxir` and `xx_network` groups on [git.xx.network](https://git.xx.network/). The documentation below describes the software they run, how the teams can use them, and information for the IT team on their maintenance. Any changes that need to be made to this setup should be told to Sydney Anne.

## Installed Software

The CI runners are based off a normal install of Ubuntu Server 20.04.3.

The following software is installed onto the Android CI VM for builds:

- GoLang (version 1.17.5)
- Java OpenJDK 8
- Android SDK Tools (version 7583922)
- Android platform SDK (version 25)
- Android platform SDK (version 29)
- Android platform SDK (version 30)
- Android platform tools
- Android build tools (version 29.0.3)
- Android Emulator
- Android Emulator system image (API version 25, x86, with Google APIs)

Additionally, the following tools are explicitly installed:

- wget
- curl
- tar
- unzip

Software not on the above lists may be available, but cannot be relied upon if Ubuntu removes them from the base install in a future update.

## Migrating to the new SDK version

Renaming the `$ANDROID_HOME` environment variable to be `$ANDROID_SDK_ROOT` is recommended for tools to continue finding the SDK. `$ANDROID_HOME` is deprecated ([see here for more details](https://developer.android.com/studio/command-line/variables)) and should no longer be used.

## Using the Android CI

You need to tag the builds that need the Android tooling in your `.gitlab-ci.yml` file with the `android` tag. (If you're unfamiliar with what a `.gitlab-ci.yml` file is, [GitLab describes it here.](https://docs.gitlab.com/ee/ci/yaml/gitlab_ci_yaml.html)) An example is below. This should only be done for jobs where the Android SDK tools are directly required, as job capacity is very limited.

When using the `android` tag, you need to ensure that `/android-sdk/platform-tools/` is in your `$PATH` environment variable, as well as setting the `$ANDROID_SDK_ROOT` environment variable to `/android-sdk`. Both of these can be done in a `before_script` if you have multiple jobs that use the `android` tag, or done in the `script` part of your job for just one.

You may optionally want to add `/usr/local/go/bin` to your `$PATH` if you plan to build Go programs for Android in your job, such as building client bindings.

```yml
stages:
  - build

before_script:
  - export ANDROID_SDK_ROOT=/android-sdk
  - export PATH=/android-sdk/platform-tools/:$PATH

app-build:
  tags:
    - android
  stage: build
  script:
    - commands
    - to
    - build
    - your
    - app
```

---

# IT Team Information

At the moment, these are VMware Fusion 12 VM images running on our bank of Mac Mini CI servers.

## VM Install Script

This is the exact script used to set up an Android CI VM image. Any changes to the CI VM must be put into this script by Sydney Anne.

```sh
#!/usr/bin/env bash
set -e

# --- System ---
# Ensure we're up to date
sudo apt update
sudo apt upgrade -y
# Firewall
sudo apt-get install -y ufw fail2ban
sudo ufw allow ssh
yes | sudo ufw enable

# --- Java ---
sudo apt-get install -y openjdk-8-jdk-headless

# --- Android SDK ---
sudo apt-get install -y wget tar unzip lib32stdc++6 lib32z1
sudo mkdir /android-sdk
# We direct the zip directly into the unzip tool to prevent writing dead data to the VM drive
wget -qO- https://dl.google.com/android/repository/commandlinetools-linux-7583922_latest.zip | sudo busybox unzip -d /android-sdk -
sudo mv /android-sdk/cmdline-tools/ /android-sdk/tools
sudo mkdir /android-sdk/cmdline-tools
sudo mv /android-sdk/tools /android-sdk/cmdline-tools/tools
sudo chmod +x /android-sdk/cmdline-tools/tools/bin/*
yes | sudo /android-sdk/cmdline-tools/tools/bin/sdkmanager --licenses --no_https
yes | sudo /android-sdk/cmdline-tools/tools/bin/sdkmanager --no_https "emulator" "platform-tools" "platforms;android-25" "platforms;android-29" "platforms;android-30" "build-tools;29.0.3"  "system-images;android-25;google_apis;x86" "ndk-bundle"

# --- Go ---
sudo apt-get install -y wget
wget -qO- https://go.dev/dl/go1.17.5.linux-amd64.tar.gz | sudo tar xzf - -C /usr/local

# --- GitLab Runner ---
# GitLab Runner
curl -L "https://packages.gitlab.com/install/repositories/runner/gitlab-runner/script.deb.sh" | sudo bash
export GITLAB_RUNNER_DISABLE_SKEL=true; sudo -E apt-get install -y gitlab-runner
sudo shutdown now
```
